searchData={"items":[{"type":"module","title":"RSProtect","doc":"Reed-Solomon encoder/decoder wrapper using Rust NIF.\n\nWraps the `reed-solomon` Rust crate to provide robust\nerror-correcting codes for binary data. This library is suitable for\ntransmitting binary packets over noisy links with optional parity.","ref":"RSProtect.html"},{"type":"module","title":"Examples - RSProtect","doc":"iex> {:ok, codeword} = RSProtect.encode(\"hello\", 4)\n    iex> {:ok, original} = RSProtect.correct(codeword, 4)\n    iex> original == \"hello\"\n    true","ref":"RSProtect.html#module-examples"},{"type":"function","title":"RSProtect.correct/3","doc":"Decode/correct a binary codeword and attempts to correct up to N/2 errors.","ref":"RSProtect.html#correct/3"},{"type":"function","title":"Parameters - RSProtect.correct/3","doc":"- `codeword`: binary of data + parity\n- `parity_bytes`: number of parity bytes originally used\n- 'known_erasures': offsets of known erasures (optional)","ref":"RSProtect.html#correct/3-parameters"},{"type":"function","title":"Returns - RSProtect.correct/3","doc":"- `{:ok, original_data}` on success\n- `:error` if the message cannot be corrected","ref":"RSProtect.html#correct/3-returns"},{"type":"function","title":"RSProtect.correct_err_count/3","doc":"Decode/Correct a binary codeword and attempts to correct up to N/2 errors.\nSame as `correct/2`, but returns the number of errors corrected.","ref":"RSProtect.html#correct_err_count/3"},{"type":"function","title":"Parameters - RSProtect.correct_err_count/3","doc":"- `codeword`: binary of data + parity\n- `parity_bytes`: number of parity bytes originally used\n- 'known_erasures': offsets of known erasures (optional)","ref":"RSProtect.html#correct_err_count/3-parameters"},{"type":"function","title":"Returns - RSProtect.correct_err_count/3","doc":"- `{:ok, original_data, err_count}` on success\n- `:error` if the message cannot be corrected","ref":"RSProtect.html#correct_err_count/3-returns"},{"type":"function","title":"RSProtect.encode/2","doc":"Encodes a binary by appending N parity bytes for error correction.","ref":"RSProtect.html#encode/2"},{"type":"function","title":"Parameters - RSProtect.encode/2","doc":"- `data`: binary to encode\n- `parity_bytes`: number of bytes to use as parity (must be >= 2)","ref":"RSProtect.html#encode/2-parameters"},{"type":"function","title":"Returns - RSProtect.encode/2","doc":"- `{:ok, binary}` with appended parity\n- `:error` on failure","ref":"RSProtect.html#encode/2-returns"},{"type":"function","title":"RSProtect.encode_ecc/2","doc":"Encodes a binary by appending N parity bytes for error correction.\nAs encode/2, except that it only returns the parity bytes.","ref":"RSProtect.html#encode_ecc/2"},{"type":"function","title":"RSProtect.is_corrupted/2","doc":"Check if a given codeword is corrupted (detectable by RS).","ref":"RSProtect.html#is_corrupted/2"},{"type":"extras","title":"RSProtect","doc":"# RSProtect\n\nRSProtect is an Elixir wrapper around the `reed-solomon` Rust crate using Rustler.\nIt provides fast, pure-Rust Reed-Solomon encoding and decoding for binary data.\nProtection is implemented on a per byte basis and an ECC/Parity code will be generated\nof length N, which will protect and correct against up to N/2 errors or erasures in the\nsource. This makes it useful for protecting short binaries against corruption in transmission","ref":"readme.html"},{"type":"extras","title":"Features - RSProtect","doc":"- Encode flat binary messages with added parity bytes\n- Decode and correct up to `floor(parity_bytes / 2)` corrupted bytes with correct/2, correct/3\n- Detect uncorrectable errors\n- Get the number of corrections made with correct_err_count/2, correct_err_count/3\n- Detect whether a message is corrupted with is_corrupted/1","ref":"readme.html#features"},{"type":"extras","title":"Installation - RSProtect","doc":"Add to `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:rs_protect, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - RSProtect","doc":"```elixir\niex> data = <<1, 2, 3, 4, 5>>\niex> {:ok, encoded} = RSProtect.encode(data, 4)\niex> RSProtect.is_corrupted(encoded, 4)\nfalse\niex> {:ok, decoded} = RSProtect.correct(encoded, 4)\ndecoded == data\n\niex> corrupted = :binary.replace(encoded, <<2>>, <<42>>, global: false)\niex> RSProtect.is_corrupted(corrupted, 4)\ntrue\niex> {:ok, {recovered, count}} = RSProtect.correct_err_count(corrupted, 4)\n{:ok, ^data, 1}\n```","ref":"readme.html#usage"},{"type":"extras","title":"Dynamic Parity Strategy - RSProtect","doc":"```elixir\ndef choose_parity(bytes) when byte_size(bytes) > 80, do: 16\nchoose_parity(_), do: 4\n```","ref":"readme.html#dynamic-parity-strategy"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}